jdahlin - in flumotion/trunk: . flumotion/component/consumers/disker flumotion/component/consumers/httpstreamer flumotion/component/consumers/shout2 flumotion/component/encoders/dirac flumotion/component/encoders/jpeg flumotion/component/encoders/mulaw flumotion/component/encoders/smoke flumotion/component/encoders/speex flumotion/component/encoders/theora flumotion/component/encoders/vorbis flumotion/component/plugs/cortado flumotion/component/producers/audiotest flumotion/component/producers/bttv flumotion/component/producers/firewire flumotion/component/producers/soundcard flumotion/component/producers/videotest flumotion/component/producers/webcam flumotion/test flumotion/ui flumotion/wizard

flumotion-commit at lists.fluendo.com flumotion-commit at lists.fluendo.com
Mon Apr 28 16:58:15 CEST 2008


Author: jdahlin
Date: Mon Apr 28 16:58:15 2008
New Revision: 6577

Log:
2008-04-28  Johan Dahlin  <johan at flumotion.com>

    * flumotion/component/consumers/disker/disker_wizard.py:
    * flumotion/component/consumers/httpstreamer/httpstreamer_wizard.py:
    * flumotion/component/consumers/shout2/shout2_wizard.py:
    * flumotion/component/encoders/dirac/dirac_wizard.py:
    * flumotion/component/encoders/jpeg/jpeg_wizard.py:
    * flumotion/component/encoders/mulaw/mulaw_wizard.py:
    * flumotion/component/encoders/smoke/smoke_wizard.py:
    * flumotion/component/encoders/speex/speex_wizard.py:
    * flumotion/component/encoders/theora/theora_wizard.py:
    * flumotion/component/encoders/vorbis/vorbis_wizard.py:
    * flumotion/component/plugs/cortado/cortado_wizard.py:
    * flumotion/component/producers/audiotest/audiotest_wizard.py:
    * flumotion/component/producers/bttv/bttv_wizard.py:
    * flumotion/component/producers/firewire/firewire_wizard.py:
    * flumotion/component/producers/soundcard/soundcard_wizard.py:
    * flumotion/component/producers/videotest/videotest_wizard.py:
    * flumotion/component/producers/webcam/webcam_wizard.py:
    * flumotion/test/test_wizard.py:
    * flumotion/ui/wizard.py:
    * flumotion/wizard/basesteps.py:
    * flumotion/wizard/configurationwizard.py:
    * flumotion/wizard/consumptionsteps.py:
    * flumotion/wizard/conversionsteps.py:
    * flumotion/wizard/interfaces.py:
    * flumotion/wizard/overlaystep.py:
    * flumotion/wizard/productionsteps.py:
    * flumotion/wizard/worker.py:
    * flumotion/wizard/workerstep.py:
    Rename wizard variables, private and public API to use camelCase
    instead of under_scores.



Modified:
   flumotion/trunk/ChangeLog
   flumotion/trunk/flumotion/component/consumers/disker/disker_wizard.py
   flumotion/trunk/flumotion/component/consumers/httpstreamer/httpstreamer_wizard.py
   flumotion/trunk/flumotion/component/consumers/shout2/shout2_wizard.py
   flumotion/trunk/flumotion/component/encoders/dirac/dirac_wizard.py
   flumotion/trunk/flumotion/component/encoders/jpeg/jpeg_wizard.py
   flumotion/trunk/flumotion/component/encoders/mulaw/mulaw_wizard.py
   flumotion/trunk/flumotion/component/encoders/smoke/smoke_wizard.py
   flumotion/trunk/flumotion/component/encoders/speex/speex_wizard.py
   flumotion/trunk/flumotion/component/encoders/theora/theora_wizard.py
   flumotion/trunk/flumotion/component/encoders/vorbis/vorbis_wizard.py
   flumotion/trunk/flumotion/component/plugs/cortado/cortado_wizard.py
   flumotion/trunk/flumotion/component/producers/audiotest/audiotest_wizard.py
   flumotion/trunk/flumotion/component/producers/bttv/bttv_wizard.py
   flumotion/trunk/flumotion/component/producers/firewire/firewire_wizard.py
   flumotion/trunk/flumotion/component/producers/soundcard/soundcard_wizard.py
   flumotion/trunk/flumotion/component/producers/videotest/videotest_wizard.py
   flumotion/trunk/flumotion/component/producers/webcam/webcam_wizard.py
   flumotion/trunk/flumotion/test/test_wizard.py
   flumotion/trunk/flumotion/ui/wizard.py
   flumotion/trunk/flumotion/wizard/basesteps.py
   flumotion/trunk/flumotion/wizard/configurationwizard.py
   flumotion/trunk/flumotion/wizard/consumptionsteps.py
   flumotion/trunk/flumotion/wizard/conversionsteps.py
   flumotion/trunk/flumotion/wizard/interfaces.py
   flumotion/trunk/flumotion/wizard/overlaystep.py
   flumotion/trunk/flumotion/wizard/productionsteps.py
   flumotion/trunk/flumotion/wizard/worker.py
   flumotion/trunk/flumotion/wizard/workerstep.py

Modified: flumotion/trunk/ChangeLog
==============================================================================
--- flumotion/trunk/ChangeLog	(original)
+++ flumotion/trunk/ChangeLog	Mon Apr 28 16:58:15 2008
@@ -1,5 +1,38 @@
 2008-04-28  Johan Dahlin  <johan at flumotion.com>
 
+	* flumotion/component/consumers/disker/disker_wizard.py:
+	* flumotion/component/consumers/httpstreamer/httpstreamer_wizard.py:
+	* flumotion/component/consumers/shout2/shout2_wizard.py:
+	* flumotion/component/encoders/dirac/dirac_wizard.py:
+	* flumotion/component/encoders/jpeg/jpeg_wizard.py:
+	* flumotion/component/encoders/mulaw/mulaw_wizard.py:
+	* flumotion/component/encoders/smoke/smoke_wizard.py:
+	* flumotion/component/encoders/speex/speex_wizard.py:
+	* flumotion/component/encoders/theora/theora_wizard.py:
+	* flumotion/component/encoders/vorbis/vorbis_wizard.py:
+	* flumotion/component/plugs/cortado/cortado_wizard.py:
+	* flumotion/component/producers/audiotest/audiotest_wizard.py:
+	* flumotion/component/producers/bttv/bttv_wizard.py:
+	* flumotion/component/producers/firewire/firewire_wizard.py:
+	* flumotion/component/producers/soundcard/soundcard_wizard.py:
+	* flumotion/component/producers/videotest/videotest_wizard.py:
+	* flumotion/component/producers/webcam/webcam_wizard.py:
+	* flumotion/test/test_wizard.py:
+	* flumotion/ui/wizard.py:
+	* flumotion/wizard/basesteps.py:
+	* flumotion/wizard/configurationwizard.py:
+	* flumotion/wizard/consumptionsteps.py:
+	* flumotion/wizard/conversionsteps.py:
+	* flumotion/wizard/interfaces.py:
+	* flumotion/wizard/overlaystep.py:
+	* flumotion/wizard/productionsteps.py:
+	* flumotion/wizard/worker.py:
+	* flumotion/wizard/workerstep.py:
+	Rename wizard variables, private and public API to use camelCase
+	instead of under_scores.
+
+2008-04-28  Johan Dahlin  <johan at flumotion.com>
+
 	* flumotion/admin/admin.py:
 	* flumotion/component/consumers/httpstreamer/httpstreamer_wizard.py:
 	* flumotion/wizard/conversionsteps.py:

Modified: flumotion/trunk/flumotion/component/consumers/disker/disker_wizard.py
==============================================================================
--- flumotion/trunk/flumotion/component/consumers/disker/disker_wizard.py	(original)
+++ flumotion/trunk/flumotion/component/consumers/disker/disker_wizard.py	Mon Apr 28 16:58:15 2008
@@ -135,9 +135,9 @@
                         'directory',
                         'start_recording'])
 
-    def worker_changed(self, worker):
+    def workerChanged(self, worker):
         self.model.worker = worker
-        self.wizard.require_elements(self.worker, 'multifdsink')
+        self.wizard.requireElements(self.worker, 'multifdsink')
 
     # Private
 

Modified: flumotion/trunk/flumotion/component/consumers/httpstreamer/httpstreamer_wizard.py
==============================================================================
--- flumotion/trunk/flumotion/component/consumers/shout2/shout2_wizard.py	(original)
+++ flumotion/trunk/flumotion/component/consumers/shout2/shout2_wizard.py	Mon Apr 28 16:58:15 2008
@@ -74,9 +74,9 @@
                         'description',
                         'url'])
 
-    def worker_changed(self, worker):
+    def workerChanged(self, worker):
         self.model.worker = worker
-        self.wizard.check_elements(worker, 'shout2send')
+        self.wizard.checkElements(worker, 'shout2send')
 
 
 class Shout2BothStep(Shout2Step):

Modified: flumotion/trunk/flumotion/component/encoders/dirac/dirac_wizard.py
==============================================================================
--- flumotion/trunk/flumotion/component/encoders/dirac/dirac_wizard.py	(original)
+++ flumotion/trunk/flumotion/component/encoders/dirac/dirac_wizard.py	Mon Apr 28 16:58:15 2008
@@ -55,13 +55,13 @@
         self.add_proxy(self.model.properties,
                        ['bitrate'])
 
-    def worker_changed(self, worker):
+    def workerChanged(self, worker):
         self.model.worker = worker
 
         self.wizard.debug('running Dirac checks')
         # FIXME: what happens to this deferred ? Does it get fired into the
         # unknown ? Should we wait on it ?
-        self.wizard.require_elements(worker, 'schroenc')
+        self.wizard.requireElements(worker, 'schroenc')
 
 class DiracWizardPlugin(object):
     implements(IEncoderPlugin)

Modified: flumotion/trunk/flumotion/component/encoders/jpeg/jpeg_wizard.py
==============================================================================
--- flumotion/trunk/flumotion/component/encoders/jpeg/jpeg_wizard.py	(original)
+++ flumotion/trunk/flumotion/component/encoders/jpeg/jpeg_wizard.py	Mon Apr 28 16:58:15 2008
@@ -71,9 +71,9 @@
         self.add_proxy(self.model.properties,
                        ['framerate', 'quality'])
 
-    def worker_changed(self, worker):
+    def workerChanged(self, worker):
         self.model.worker = worker
-        self.wizard.require_elements(worker, 'jpegenc')
+        self.wizard.requireElements(worker, 'jpegenc')
 
 
 class JPEGWizardPlugin(object):

Modified: flumotion/trunk/flumotion/component/encoders/mulaw/mulaw_wizard.py
==============================================================================
--- flumotion/trunk/flumotion/component/encoders/mulaw/mulaw_wizard.py	(original)
+++ flumotion/trunk/flumotion/component/encoders/mulaw/mulaw_wizard.py	Mon Apr 28 16:58:15 2008
@@ -46,9 +46,9 @@
 
     # WizardStep
 
-    def worker_changed(self, worker):
+    def workerChanged(self, worker):
         self.model.worker = worker
-        self.wizard.require_elements(worker, 'mulawenc')
+        self.wizard.requireElements(worker, 'mulawenc')
 
 
 class MulawWizardPlugin(object):

Modified: flumotion/trunk/flumotion/component/encoders/smoke/smoke_wizard.py
==============================================================================
--- flumotion/trunk/flumotion/component/encoders/smoke/smoke_wizard.py	(original)
+++ flumotion/trunk/flumotion/component/encoders/smoke/smoke_wizard.py	Mon Apr 28 16:58:15 2008
@@ -46,9 +46,9 @@
 
     # WizardStep
 
-    def worker_changed(self, worker):
+    def workerChanged(self, worker):
         self.model.worker = worker
-        self.wizard.require_elements(worker, 'smokeenc')
+        self.wizard.requireElements(worker, 'smokeenc')
 
 
 class SmokeWizardPlugin(object):

Modified: flumotion/trunk/flumotion/component/encoders/speex/speex_wizard.py
==============================================================================
--- flumotion/trunk/flumotion/component/encoders/speex/speex_wizard.py	(original)
+++ flumotion/trunk/flumotion/component/encoders/speex/speex_wizard.py	Mon Apr 28 16:58:15 2008
@@ -62,9 +62,9 @@
 
         self.add_proxy(self.model.properties, ['bitrate'])
 
-    def worker_changed(self, worker):
+    def workerChanged(self, worker):
         self.model.worker = worker
-        self.wizard.require_elements(worker, 'speexenc')
+        self.wizard.requireElements(worker, 'speexenc')
 
 
 class SpeexWizardPlugin(object):

Modified: flumotion/trunk/flumotion/component/encoders/theora/theora_wizard.py
==============================================================================
--- flumotion/trunk/flumotion/component/encoders/theora/theora_wizard.py	(original)
+++ flumotion/trunk/flumotion/component/encoders/theora/theora_wizard.py	Mon Apr 28 16:58:15 2008
@@ -108,22 +108,22 @@
         # a number of frames, so we need the framerate and calculate
         # we need to go through the Step (which is the view) because models
         # don't have references to other models
-        producer = self.wizard.get_step('Production').get_video_producer()
+        producer = self.wizard.getStep('Production').getVideoProducer()
         self.model.framerate = producer.properties['framerate']
         self.debug('Framerate of video producer: %r' % self.model.framerate)
         step = 1 / self.model.framerate
         page = 1.0
         self.keyframe_delta.set_increments(step, page)
 
-    def worker_changed(self, worker):
+    def workerChanged(self, worker):
         self.model.worker = worker
 
         def hasTheora(unused, worker):
-            self.wizard.run_in_worker(
+            self.wizard.runInWorker(
                 worker, 'flumotion.worker.checks.encoder', 'checkTheora')
 
         self.wizard.debug('running Theora checks')
-        d = self.wizard.require_elements(worker, 'theoraenc')
+        d = self.wizard.requireElements(worker, 'theoraenc')
         d.addCallback(hasTheora, worker)
 
     # Callbacks

Modified: flumotion/trunk/flumotion/component/encoders/vorbis/vorbis_wizard.py
==============================================================================
--- flumotion/trunk/flumotion/component/encoders/vorbis/vorbis_wizard.py	(original)
+++ flumotion/trunk/flumotion/component/encoders/vorbis/vorbis_wizard.py	Mon Apr 28 16:58:15 2008
@@ -76,15 +76,15 @@
         self.add_proxy(self.model.properties,
                        ['bitrate', 'quality'])
 
-    def worker_changed(self, worker):
+    def workerChanged(self, worker):
         self.model.worker = worker
 
         def hasVorbis(unused, worker):
-            self.wizard.run_in_worker(
+            self.wizard.runInWorker(
                 worker, 'flumotion.worker.checks.encoder', 'checkVorbis')
 
         self.wizard.debug('running Vorbis checks')
-        d = self.wizard.require_elements(worker, 'vorbisenc')
+        d = self.wizard.requireElements(worker, 'vorbisenc')
         d.addCallback(hasVorbis, worker)
 
     # Callbacks

Modified: flumotion/trunk/flumotion/component/plugs/cortado/cortado_wizard.py
==============================================================================
--- flumotion/trunk/flumotion/component/plugs/cortado/cortado_wizard.py	(original)
+++ flumotion/trunk/flumotion/component/plugs/cortado/cortado_wizard.py	Mon Apr 28 16:58:15 2008
@@ -114,8 +114,8 @@
     def __init__(self, wizard):
         self.wizard = wizard
 
-    def worker_changed(self, worker):
-        d = self.wizard.run_in_worker(
+    def workerChanged(self, worker):
+        d = self.wizard.runInWorker(
             worker,
             'flumotion.worker.checks.cortado', 'checkCortado')
         def check(found):

Modified: flumotion/trunk/flumotion/component/producers/audiotest/audiotest_wizard.py
==============================================================================
--- flumotion/trunk/flumotion/component/producers/audiotest/audiotest_wizard.py	(original)
+++ flumotion/trunk/flumotion/component/producers/audiotest/audiotest_wizard.py	Mon Apr 28 16:58:15 2008
@@ -63,11 +63,11 @@
 
         self.rate.set_sensitive(True)
 
-    def worker_changed(self, worker):
+    def workerChanged(self, worker):
         self.model.worker = worker
-        self.wizard.require_elements(worker, 'audiotestsrc')
+        self.wizard.requireElements(worker, 'audiotestsrc')
 
-    def get_next(self):
+    def getNext(self):
         return None
 
 

Modified: flumotion/trunk/flumotion/component/producers/bttv/bttv_wizard.py
==============================================================================
--- flumotion/trunk/flumotion/component/producers/bttv/bttv_wizard.py	(original)
+++ flumotion/trunk/flumotion/component/producers/bttv/bttv_wizard.py	Mon Apr 28 16:58:15 2008
@@ -85,7 +85,7 @@
 
         self._in_setup = False
 
-    def worker_changed(self, worker):
+    def workerChanged(self, worker):
         self.model.worker = worker
         self._clear_combos()
         self._run_checks()
@@ -110,7 +110,7 @@
             N_("Probing TV-card, this can take a while...")),
                             id='tvcard-check')
         self.wizard.add_msg(msg)
-        d = self.run_in_worker('flumotion.worker.checks.video', 'checkTVCard',
+        d = self.runInWorker('flumotion.worker.checks.video', 'checkTVCard',
                                device, id='tvcard-check')
 
         def errRemoteRunFailure(failure):

Modified: flumotion/trunk/flumotion/component/producers/firewire/firewire_wizard.py
==============================================================================
--- flumotion/trunk/flumotion/component/producers/firewire/firewire_wizard.py	(original)
+++ flumotion/trunk/flumotion/component/producers/firewire/firewire_wizard.py	Mon Apr 28 16:58:15 2008
@@ -76,15 +76,15 @@
 
     # WizardStep
 
-    def worker_changed(self, worker):
+    def workerChanged(self, worker):
         self.model.worker = worker
         self._run_checks()
 
     # Private
 
-    def _set_sensitive(self, is_sensitive):
+    def _setSensitive(self, is_sensitive):
         self.vbox_controls.set_sensitive(is_sensitive)
-        self.wizard.block_next(not is_sensitive)
+        self.wizard.blockNext(not is_sensitive)
 
     def _update_output_format(self):
         self._update_label_camera_settings()
@@ -173,11 +173,11 @@
         return dict(sw=sw,sh=sh,ow=ow,oh=oh)
 
     def _run_checks(self):
-        self._set_sensitive(False)
+        self._setSensitive(False)
         msg = messages.Info(T_(N_('Checking for Firewire device...')),
             id='firewire-check')
         self.wizard.add_msg(msg)
-        d = self.run_in_worker('flumotion.worker.checks.gst010', 'check1394',
+        d = self.runInWorker('flumotion.worker.checks.gst010', 'check1394',
             id='firewire-check')
 
         def firewireCheckDone(options):
@@ -190,7 +190,7 @@
             for i, height in enumerate(self._input_heights):
                 values.append(('%d pixels' % height, i))
             self.combobox_scaled_height.prefill(values)
-            self._set_sensitive(True)
+            self._setSensitive(True)
             self._update_output_format()
 
         def trapRemoteFailure(failure):
@@ -243,7 +243,7 @@
         self.frame_capture.hide()
         self.frame_output_format.hide()
 
-    def get_next(self):
+    def getNext(self):
         return None
 
 
@@ -255,7 +255,7 @@
     def getProductionStep(self, type):
         if type == 'audio':
             # Only show firewire audio if we're using firewire video
-            source_step = self.wizard.get_step('Production')
+            source_step = self.wizard.getStep('Production')
             if source_step.video.get_active() == 'firewire-producer':
                 return
             return FireWireAudioStep(self.wizard, FireWireProducer())

Modified: flumotion/trunk/flumotion/component/producers/soundcard/soundcard_wizard.py
==============================================================================
--- flumotion/trunk/flumotion/component/producers/soundcard/soundcard_wizard.py	(original)
+++ flumotion/trunk/flumotion/component/producers/soundcard/soundcard_wizard.py	Mon Apr 28 16:58:15 2008
@@ -112,13 +112,13 @@
 
         self._block_update = False
 
-    def worker_changed(self, worker):
+    def workerChanged(self, worker):
         self.model.worker = worker
         self._clear_combos()
         self._update_devices()
         self._update_inputs()
 
-    def get_next(self):
+    def getNext(self):
         return None
 
     # Private
@@ -157,7 +157,7 @@
             N_("Probing soundcard, this can take a while...")),
                             id='soundcard-check')
         self.wizard.add_msg(msg)
-        d = self.run_in_worker(
+        d = self.runInWorker(
             'flumotion.worker.checks.audio', 'checkMixerTracks',
             element_name, device, channels, id='soundcard-check')
 

Modified: flumotion/trunk/flumotion/component/producers/videotest/videotest_wizard.py
==============================================================================
--- flumotion/trunk/flumotion/component/producers/videotest/videotest_wizard.py	(original)
+++ flumotion/trunk/flumotion/component/producers/videotest/videotest_wizard.py	Mon Apr 28 16:58:15 2008
@@ -74,9 +74,9 @@
         sizegroup.add_widget(self.height)
         sizegroup.add_widget(self.framerate)
 
-    def worker_changed(self, worker):
+    def workerChanged(self, worker):
         self.model.worker = worker
-        self.wizard.require_elements(worker, 'videotestsrc', 'level')
+        self.wizard.requireElements(worker, 'videotestsrc', 'level')
 
 
 class VideoTestWizardPlugin(object):

Modified: flumotion/trunk/flumotion/component/producers/webcam/webcam_wizard.py
==============================================================================
--- flumotion/trunk/flumotion/component/producers/webcam/webcam_wizard.py	(original)
+++ flumotion/trunk/flumotion/component/producers/webcam/webcam_wizard.py	Mon Apr 28 16:58:15 2008
@@ -74,7 +74,7 @@
 
         self._in_setup = False
 
-    def worker_changed(self, worker):
+    def workerChanged(self, worker):
         self.model.worker = worker
         self._clear()
         self._run_checks()
@@ -98,7 +98,7 @@
                 N_("Probing webcam, this can take a while...")),
             id='webcam-check')
         self.wizard.add_msg(msg)
-        d = self.run_in_worker('flumotion.worker.checks.video', 'checkWebcam',
+        d = self.runInWorker('flumotion.worker.checks.video', 'checkWebcam',
                            device, id='webcam-check')
 
         def errRemoteRunFailure(failure):

Modified: flumotion/trunk/flumotion/test/test_wizard.py
==============================================================================
--- flumotion/trunk/flumotion/test/test_wizard.py	(original)
+++ flumotion/trunk/flumotion/test/test_wizard.py	Mon Apr 28 16:58:15 2008
@@ -55,8 +55,8 @@
             self.assertEqual(s.name, s.get_name())
 
             if s.get_name() != 'Summary':
-                get_next_ret = s.get_next()
-                self.assert_(not get_next_ret or isinstance(get_next_ret, str))
+                getNextRet = s.getNext()
+                self.assert_(not getNextRet or isinstance(getNextRet, str))
 
     def testStepComponentProperties(self):
         for s in self.steps:

Modified: flumotion/trunk/flumotion/ui/wizard.py
==============================================================================
--- flumotion/trunk/flumotion/ui/wizard.py	(original)
+++ flumotion/trunk/flumotion/ui/wizard.py	Mon Apr 28 16:58:15 2008
@@ -71,7 +71,7 @@
     def current(self):
         return self.l[self.pos]
 
-    def skip_to(self, key):
+    def skipTo(self, key):
         for i, item in enumerate(self.l):
             if key(item):
                 self.pos = i
@@ -120,7 +120,7 @@
 
     # Required vmethods
 
-    def get_next(self):
+    def getNext(self):
         """Called when the user presses next in the wizard.
         @returns: name of next step
         @rtype: L{WizardStep} instance, deferred or None.
@@ -172,7 +172,7 @@
         self.sidebar.set_sections([(x.section, x.name) for x in self.sections])
         self.sidebar.connect('step-chosen', self.on_sidebar_step_chosen)
 
-        self._current_step = self.get_first_step()
+        self._current_step = self.getFirstStep()
 
     def __nonzero__(self):
         return True
@@ -181,7 +181,7 @@
         return len(self._steps)
 
     # Override this in subclass
-    def get_first_step(self):
+    def getFirstStep(self):
         raise NotImplementedError
 
     def completed(self):
@@ -189,7 +189,7 @@
 
     # Public API
 
-    def get_step(self, stepname):
+    def getStep(self, stepname):
         """Fetches a step. KeyError is raised when the step is not found.
         @param stepname: name of the step to fetch
         @type stepname: str
@@ -224,7 +224,7 @@
     def add_msg(self, msg):
         self.message_area.add_message(msg)
 
-    def block_next(self, block):
+    def blockNext(self, block):
         self.button_next.set_sensitive(not block)
         # work around a gtk+ bug #56070
         if not block:
@@ -237,7 +237,7 @@
         section = section_class(self)
         self.sidebar.push(section.section, None, section.section)
         self._stack.push(section)
-        self._set_step(section)
+        self._setStep(section)
 
         if not interactive:
             while self.show_next():
@@ -255,7 +255,7 @@
         except KeyboardInterrupt:
             pass
 
-    def _get_next_step(self):
+    def _getNextStep(self):
         if self._current_section + 1 == len(self.sections):
             self._finish(completed=True)
             return
@@ -264,32 +264,32 @@
         next_step_class = self.sections[self._current_section]
         return next_step_class(self)
 
-    def prepare_next_step(self, step):
-        next = step.get_next()
+    def prepareNextStep(self, step):
+        next = step.getNext()
         if isinstance(next, WizardStep):
             next_step = next
         elif isinstance(next, Deferred):
             d = next
-            def get_step(step):
+            def getStep(step):
                 if step is None:
-                    step = self._get_next_step()
+                    step = self._getNextStep()
                 if step is None:
                     return
-                self._show_next_step(step)
-            d.addCallback(get_step)
+                self._showNextStep(step)
+            d.addCallback(getStep)
             return
         elif next is None:
-            next_step = self._get_next_step()
+            next_step = self._getNextStep()
             if next_step is None:
                 return
         else:
             raise AssertionError(next)
 
-        self._show_next_step(next_step)
+        self._showNextStep(next_step)
 
     # Private
 
-    def _update_buttons(self, has_next):
+    def _updateButtons(self, has_next):
         # update the forward and next buttons
         # has_next: whether or not there is a next step
         can_go_back = self._stack.pos != 0
@@ -302,16 +302,16 @@
             # use APPLY, just like in gnomemeeting
             self.button_next.set_label(gtk.STOCK_APPLY)
 
-    def _set_step_icon(self, icon):
+    def _setStepIcon(self, icon):
         icon_filename = os.path.join(configure.imagedir, 'wizard', icon)
         assert os.path.exists(icon_filename)
         self.image_icon.set_from_file(icon_filename)
 
-    def _set_step_title(self, title):
+    def _setStepTitle(self, title):
         self.label_title.set_markup(
             '<span size="x-large">%s</span>' % escape(title))
 
-    def _pack_step(self, step):
+    def _packStep(self, step):
         # Remove previous step
         map(self.content_area.remove, self.content_area.get_children())
         self.message_area.clear()
@@ -329,7 +329,7 @@
             except RuntimeError:
                 pass
 
-    def _show_next_step(self, step):
+    def _showNextStep(self, step):
         self._steps[step.name] = step
 
         while not self._stack.push(step):
@@ -344,49 +344,49 @@
             self.sidebar.show_step(step.section)
 
         step.visited = True
-        self._set_step(step)
+        self._setStep(step)
 
         has_next = not hasattr(step, 'last_step')
-        self._update_buttons(has_next)
+        self._updateButtons(has_next)
 
-    def _set_step(self, step):
+    def _setStep(self, step):
         self._current_step = step
 
-        self._pack_step(step)
-        self._set_step_icon(step.icon)
-        self._set_step_title(step.name)
+        self._packStep(step)
+        self._setStepIcon(step.icon)
+        self._setStepTitle(step.name)
 
-        self._update_buttons(has_next=True)
-        self.block_next(False)
+        self._updateButtons(has_next=True)
+        self.blockNext(False)
 
-        self.before_show_step(step)
+        self.beforeShowStep(step)
 
         self.debug('showing step %r' % step)
         step.show()
         step.activated()
 
-    def _jump_to_step(self, name):
-        step = self.get_step(name)
+    def _jumpToStep(self, name):
+        step = self.getStep(name)
         # If we're jumping to the same step don't do anything to
         # avoid unnecessary ui flashes
         if step == self._current_step:
             return
-        self._stack.skip_to(lambda x: x.name == name)
+        self._stack.skipTo(lambda x: x.name == name)
         step = self._stack.current()
         self.sidebar.show_step(step.section)
-        self._current_section = self._get_section_by_name(step.section)
-        self._set_step(step)
+        self._current_section = self._getSectionByName(step.section)
+        self._setStep(step)
 
-    def _show_previous_step(self):
+    def _showPreviousStep(self):
         step = self._stack.back()
-        self._current_section = self._get_section_by_name(step.section)
-        self._set_step(step)
-        self._update_buttons(has_next=True)
+        self._current_section = self._getSectionByName(step.section)
+        self._setStep(step)
+        self._updateButtons(has_next=True)
         self.sidebar.show_step(step.section)
         has_next = not hasattr(step, 'last_step')
-        self._update_buttons(has_next)
+        self._updateButtons(has_next)
 
-    def _get_section_by_name(self, section_name):
+    def _getSectionByName(self, section_name):
         for section_class in self.sections:
             if section_class.section == section_name:
                 return self.sections.index(section_class)
@@ -410,13 +410,13 @@
         self._finish(self._use_main, completed=False)
 
     def on_button_prev_clicked(self, button):
-        self._show_previous_step()
+        self._showPreviousStep()
 
     def on_button_next_clicked(self, button):
-        self.prepare_next_step(self._current_step)
+        self.prepareNextStep(self._current_step)
 
     def on_sidebar_step_chosen(self, sidebar, name):
-        self._jump_to_step(name)
+        self._jumpToStep(name)
 
 
 gobject.type_register(SectionWizard)

Modified: flumotion/trunk/flumotion/wizard/basesteps.py
==============================================================================
--- flumotion/trunk/flumotion/wizard/basesteps.py	(original)
+++ flumotion/trunk/flumotion/wizard/basesteps.py	Mon Apr 28 16:58:15 2008
@@ -45,7 +45,7 @@
 
     # WizardStep
 
-    def get_next(self):
+    def getNext(self):
         from flumotion.wizard.overlaystep import OverlayStep
         return OverlayStep(self.wizard, self.model)
 
@@ -57,12 +57,12 @@
         self.model = model
         WorkerWizardStep.__init__(self, wizard)
 
-    def get_next(self):
-        return self.wizard.get_step('Encoding').get_audio_page()
+    def getNext(self):
+        return self.wizard.getStep('Encoding').getAudioPage()
 
 
 class AudioEncoderStep(WorkerWizardStep):
-    glade_file = 'wizard_audio_encoder.glade'
+    glade_file = 'wizard_audioEncoder.glade'
     section = _('Conversion')
 
     def __init__(self, wizard, model):
@@ -71,7 +71,7 @@
 
     # WizardStep
 
-    def get_next(self):
+    def getNext(self):
         return None
 
 
@@ -99,6 +99,6 @@
 
     # WizardStep
 
-    def get_next(self):
-        return self.wizard.get_step('Consumption').get_next(self)
+    def getNext(self):
+        return self.wizard.getStep('Consumption').getNext(self)
 

Modified: flumotion/trunk/flumotion/wizard/configurationwizard.py
==============================================================================
--- flumotion/trunk/flumotion/wizard/configurationwizard.py	(original)
+++ flumotion/trunk/flumotion/wizard/configurationwizard.py	Mon Apr 28 16:58:15 2008
@@ -63,7 +63,7 @@
     section = _('Welcome')
     icon = 'wizard.png'
 
-    def get_next(self):
+    def getNext(self):
         return None
 
 
@@ -90,7 +90,7 @@
             (_('Creative Commons'), 'CC'),
             (_('Commercial'), 'Commercial')])
 
-    def get_next(self):
+    def getNext(self):
         return None
 
     # Callbacks
@@ -108,7 +108,7 @@
 
     # WizardStep
 
-    def get_next(self):
+    def getNext(self):
         return None
 
 
@@ -129,18 +129,18 @@
         self._tasks = []
         self._admin = admin
         self._workerHeavenState = None
-        self._last_worker = 0 # combo id last worker from step to step
+        self._lastWorker = 0 # combo id last worker from step to step
 
         self._flowName = 'default'
 
-        self._worker_list = WorkerList()
-        self.top_vbox.pack_start(self._worker_list, False, False)
-        self._worker_list.connect('worker-selected',
+        self._workerList = WorkerList()
+        self.top_vbox.pack_start(self._workerList, False, False)
+        self._workerList.connect('worker-selected',
                                   self.on_combobox_worker_changed)
 
     # SectionWizard
 
-    def get_first_step(self):
+    def getFirstStep(self):
         return WelcomeStep(self)
 
     def completed(self):
@@ -152,28 +152,28 @@
 
     def run(self, interactive, workerHeavenState, main=True):
         self._workerHeavenState = workerHeavenState
-        self._worker_list.set_worker_heaven_state(workerHeavenState)
+        self._workerList.setWorkerHeavenState(workerHeavenState)
 
         SectionWizard.run(self, interactive, main)
 
-    def before_show_step(self, step):
+    def beforeShowStep(self, step):
         if isinstance(step, WorkerWizardStep):
-            self._worker_list.show()
-            self._worker_list.notify_selected()
+            self._workerList.show()
+            self._workerList.notifySelected()
         else:
-            self._worker_list.hide()
+            self._workerList.hide()
 
-        self._setup_worker(step, self._worker_list.get_worker())
+        self._setupWorker(step, self._workerList.getWorker())
 
-    def prepare_next_step(self, step):
-        self._setup_worker(step, self._worker_list.get_worker())
-        SectionWizard.prepare_next_step(self, step)
+    def prepareNextStep(self, step):
+        self._setupWorker(step, self._workerList.getWorker())
+        SectionWizard.prepareNextStep(self, step)
 
-    def block_next(self, block):
+    def blockNext(self, block):
         # Do not block/unblock if we have tasks running
         if self._tasks:
             return
-        SectionWizard.block_next(self, block)
+        SectionWizard.blockNext(self, block)
 
     # Public API
 
@@ -188,7 +188,7 @@
         self.info("waiting for task %s" % (taskName,))
         if not self._tasks:
             self.window1.window.set_cursor(self._cursorWatch)
-            self.block_next(True)
+            self.blockNext(True)
         self._tasks.append(taskName)
 
     def taskFinished(self, blockNext=False):
@@ -199,7 +199,7 @@
         self.info("task %s has now finished" % (taskName,))
         if not self._tasks:
             self.window1.window.set_cursor(None)
-            self.block_next(blockNext)
+            self.blockNext(blockNext)
 
     def pendingTask(self):
         """Returns true if there are any pending tasks
@@ -212,7 +212,7 @@
         @return: if we have audio
         @rtype: bool
         """
-        source_step = self.get_step('Production')
+        source_step = self.getStep('Production')
         return source_step.hasAudio()
 
     def hasVideo(self):
@@ -220,8 +220,8 @@
         @return: if we have video
         @rtype: bool
         """
-        source_step = self.get_step('Production')
-        return bool(source_step.get_video_producer())
+        source_step = self.getStep('Production')
+        return bool(source_step.getVideoProducer())
 
     def getConsumptionSteps(self):
         """Fetches the consumption steps chosen by the user
@@ -231,7 +231,7 @@
             if isinstance(step, ConsumerStep):
                 yield step
 
-    def check_elements(self, workerName, *elementNames):
+    def checkElements(self, workerName, *elementNames):
         """
         Check if the given list of GStreamer elements exist on the given worker.
 
@@ -255,7 +255,7 @@
         d.addCallback(_checkElementsCallback, workerName)
         return d
 
-    def require_elements(self, workerName, *elementNames):
+    def requireElements(self, workerName, *elementNames):
         """
         Require that the given list of GStreamer elements exists on the
         given worker. If the elements do not exist, an error message is
@@ -269,7 +269,7 @@
             return
 
         self.debug('requiring elements %r' % (elementNames,))
-        def got_missing_elements(elements, workerName):
+        def gotMissingElements(elements, workerName):
             if elements:
                 self.warning('elements %r do not exist' % (elements,))
                 f = ngettext("Worker '%s' is missing GStreamer element '%s'.",
@@ -288,12 +288,12 @@
             return elements
 
         self.waitForTask('require elements %r' % (elementNames,))
-        d = self.check_elements(workerName, *elementNames)
-        d.addCallback(got_missing_elements, workerName)
+        d = self.checkElements(workerName, *elementNames)
+        d.addCallback(gotMissingElements, workerName)
 
         return d
 
-    def check_import(self, workerName, moduleName):
+    def checkImport(self, workerName, moduleName):
         """
         Check if the given module can be imported.
 
@@ -309,7 +309,7 @@
         d = self._admin.checkImport(workerName, moduleName)
         return d
 
-    def require_import(self, workerName, moduleName, projectName=None,
+    def requireImport(self, workerName, moduleName, projectName=None,
                        projectURL=None):
         """
         Require that the given module can be imported on the given worker.
@@ -343,12 +343,12 @@
             self.add_msg(message)
             self.taskFinished(True)
 
-        d = self.check_import(workerName, moduleName)
+        d = self.checkImport(workerName, moduleName)
         d.addErrback(_checkImportErrback)
         return d
 
     # FIXME: maybe add id here for return messages ?
-    def run_in_worker(self, worker, module, function, *args, **kwargs):
+    def runInWorker(self, worker, module, function, *args, **kwargs):
         """
         Run the given function and arguments on the selected worker.
 
@@ -357,18 +357,18 @@
         @param function:
         @returns: L{twisted.internet.defer.Deferred}
         """
-        self.debug('run_in_worker(module=%r, function=%r)' % (module, function))
+        self.debug('runInWorker(module=%r, function=%r)' % (module, function))
         admin = self._admin
         if not admin:
-            self.warning('skipping run_in_worker, no admin')
+            self.warning('skipping runInWorker, no admin')
             return defer.fail(errors.FlumotionError('no admin'))
 
         if not worker:
-            self.warning('skipping run_in_worker, no worker')
+            self.warning('skipping runInWorker, no worker')
             return defer.fail(errors.FlumotionError('no worker'))
 
         def callback(result):
-            self.debug('run_in_worker callbacked a result')
+            self.debug('runInWorker callbacked a result')
             self.clear_msg(function)
 
             if not isinstance(result, messages.Result):
@@ -393,7 +393,7 @@
             return result.value
 
         def errback(failure):
-            self.debug('run_in_worker errbacked, showing error msg')
+            self.debug('runInWorker errbacked, showing error msg')
             if failure.check(errors.RemoteRunError):
                 debug = failure.value
             else:
@@ -414,7 +414,7 @@
         d.addCallback(callback)
         return d
 
-    def get_wizard_entry(self, component_type):
+    def getWizardEntry(self, component_type):
         """Fetches a wizard bundle from a specific kind of component
         @param component_type: the component type to get the wizard entry
           bundle from.
@@ -422,7 +422,7 @@
           - factory of the component
           - noBundle error: if the component lacks a wizard bundle
         """
-        def got_entry_point((filename, procname)):
+        def gotEntryPoint((filename, procname)):
             modname = pathToModuleName(filename)
             d = self._admin.getBundledFunction(modname, procname)
             self.clear_msg('wizard-bundle')
@@ -432,10 +432,10 @@
         self.waitForTask('get wizard entry %s' % (component_type,))
         self.clear_msg('wizard-bundle')
         d = self._admin.callRemote('getEntryByType', component_type, 'wizard')
-        d.addCallback(got_entry_point)
+        d.addCallback(gotEntryPoint)
         return d
 
-    def get_wizard_plug_entry(self, plug_type):
+    def _getWizardPlugEntry(self, plug_type):
         """Fetches a wizard bundle from a specific kind of plug
         @param plug_type: the plug type to get the wizard entry
           bundle from.
@@ -443,7 +443,7 @@
           - factory of the plug
           - noBundle error: if the plug lacks a wizard bundle
         """
-        def got_entry_point((filename, procname)):
+        def gotEntryPoint((filename, procname)):
             modname = pathToModuleName(filename)
             d = self._admin.getBundledFunction(modname, procname)
             self.clear_msg('wizard-bundle')
@@ -453,7 +453,7 @@
         self.waitForTask('get wizard plug %s' % (plug_type,))
         self.clear_msg('wizard-bundle')
         d = self._admin.callRemote('getPlugEntry', plug_type, 'wizard')
-        d.addCallback(got_entry_point)
+        d.addCallback(gotEntryPoint)
         return d
 
     def getWizardEntries(self, wizardTypes=None, provides=None, accepts=None):
@@ -480,7 +480,7 @@
 
     # Private
 
-    def _setup_worker(self, step, worker):
+    def _setupWorker(self, step, worker):
         # get name of active worker
         self.debug('%r setting worker to %s' % (step, worker))
         step.worker = worker
@@ -489,18 +489,18 @@
         save = WizardSaver()
         save.setFlowName(self._flowName)
 
-        source_step = self.get_step('Production')
-        save.setAudioProducer(source_step.get_audio_producer())
-        save.setVideoProducer(source_step.get_video_producer())
+        source_step = self.getStep('Production')
+        save.setAudioProducer(source_step.getAudioProducer())
+        save.setVideoProducer(source_step.getVideoProducer())
 
         if source_step.hasVideo():
-            overlay_step = self.get_step('Overlay')
+            overlay_step = self.getStep('Overlay')
             save.setVideoOverlay(overlay_step.getOverlay())
 
-        encoding_step = self.get_step('Encoding')
-        save.setAudioEncoder(encoding_step.get_audio_encoder())
-        save.setVideoEncoder(encoding_step.get_video_encoder())
-        save.setMuxer(encoding_step.get_muxer_type(), encoding_step.worker)
+        encoding_step = self.getStep('Encoding')
+        save.setAudioEncoder(encoding_step.getAudioEncoder())
+        save.setVideoEncoder(encoding_step.getVideoEncoder())
+        save.setMuxer(encoding_step.getMuxerType(), encoding_step.worker)
 
         for step in self.getConsumptionSteps():
             consumerType = step.getConsumerType()
@@ -512,7 +512,7 @@
             for porter in step.getPorters():
                 save.addPorter(porter, consumerType)
 
-        license_step = self.get_step('Content License')
+        license_step = self.getStep('Content License')
         if license_step.getLicenseType() == 'CC':
             save.setUseCCLicense(True)
 
@@ -523,15 +523,15 @@
     # Callbacks
 
     def on_combobox_worker_changed(self, combobox, worker):
-        self.debug('combobox_worker_changed, worker %r' % worker)
+        self.debug('combobox_workerChanged, worker %r' % worker)
         if worker:
             self.clear_msg('worker-error')
-            self._last_worker = worker
+            self._lastWorker = worker
             step = self._current_step
             if step and isinstance(step, WorkerWizardStep):
-                self._setup_worker(step, worker)
-                self.debug('calling %r.worker_changed' % step)
-                step.worker_changed(worker)
+                self._setupWorker(step, worker)
+                self.debug('calling %r.workerChanged' % step)
+                step.workerChanged(worker)
         else:
             msg = messages.Error(T_(
                     N_('All workers have logged out.\n'

Modified: flumotion/trunk/flumotion/wizard/consumptionsteps.py
==============================================================================
--- flumotion/trunk/flumotion/wizard/consumptionsteps.py	(original)
+++ flumotion/trunk/flumotion/wizard/consumptionsteps.py	Mon Apr 28 16:58:15 2008
@@ -59,8 +59,8 @@
                             self.shout2_video):
             checkbutton.set_property('visible', has_both)
 
-    def get_next(self, step=None):
-        steps = self._get_steps()
+    def getNext(self, step=None):
+        steps = self._getSteps()
         assert steps
 
         if step is None:
@@ -90,14 +90,14 @@
         shout2_video = self.shout2_video.get_active()
         shout2_audio_video = self.shout2_audio_video.get_active()
 
-        block_next = True
+        blockNext = True
         if ((disk and any([disk_audio, disk_video, disk_audio_video])) or
             (http and any([http_audio, http_video, http_audio_video])) or
             (shout2 and any([shout2_audio, shout2_video, shout2_audio_video]))):
-            block_next = False
-        self.wizard.block_next(block_next)
+            blockNext = False
+        self.wizard.blockNext(blockNext)
 
-    def _get_steps(self):
+    def _getSteps(self):
         uielements = []
         if self.http.get_active():
             uielements.append(

Modified: flumotion/trunk/flumotion/wizard/conversionsteps.py
==============================================================================
--- flumotion/trunk/flumotion/wizard/conversionsteps.py	(original)
+++ flumotion/trunk/flumotion/wizard/conversionsteps.py	Mon Apr 28 16:58:15 2008
@@ -45,32 +45,32 @@
     section = _('Conversion')
 
     def __init__(self, wizard):
-        self._audio_encoder = None
-        self._video_encoder = None
+        self._audioEncoder = None
+        self._videoEncoder = None
         WorkerWizardStep.__init__(self, wizard)
 
     # Public API
 
-    def get_audio_page(self):
+    def getAudioPage(self):
         if self.wizard.hasAudio():
-            return self._get_audio_page()
+            return self._getAudioPage()
         return None
 
-    def get_video_encoder(self):
+    def getVideoEncoder(self):
         """Returns the selected video encoder or None
         @returns: encoder or None
         @rtype: L{flumotion.wizard.models.VideoEncoder}
         """
-        return self._video_encoder
+        return self._videoEncoder
 
-    def get_audio_encoder(self):
+    def getAudioEncoder(self):
         """Returns the selected audio encoder or None
         @returns: encoder or None
         @rtype: L{flumotion.wizard.models.AudioEncoder}
         """
-        return self._audio_encoder
+        return self._audioEncoder
 
-    def get_muxer_type(self):
+    def getMuxerType(self):
         """Returns the component-type, such as "ogg-muxer"
         of the currently selected muxer.
         @returns: the muxer
@@ -79,7 +79,7 @@
         entry = self.muxer.get_selected()
         return entry.component_type
 
-    def get_muxer_format(self):
+    def getMuxerFormat(self):
         """Returns the format of the muxer, such as "ogg".
         @returns: the muxer format
         @rtype: string
@@ -87,21 +87,21 @@
         entry = self.muxer.get_selected()
         return entry.getProvidedMediaTypes()[0]
 
-    def get_audio_format(self):
+    def getAudioFormat(self):
         """Returns the format of the audio encoder, such as "vorbis"
         @returns: the audio format
         @rtype: string
         """
-        if self._audio_encoder:
+        if self._audioEncoder:
             entry = self.audio.get_selected()
             return entry.getProvidedMediaTypes()[0]
 
-    def get_video_format(self):
+    def getVideoFormat(self):
         """Returns the format of the video encoder, such as "theora"
         @returns: the video format
         @rtype: string
         """
-        if self._video_encoder:
+        if self._videoEncoder:
             entry = self.video.get_selected()
             return entry.getProvidedMediaTypes()[0]
 
@@ -110,15 +110,15 @@
     def activated(self):
         data = [('muxer', self.muxer)]
 
-        production = self.wizard.get_step('Production')
-        audio_producer = production.get_audio_producer()
+        production = self.wizard.getStep('Production')
+        audio_producer = production.getAudioProducer()
         if audio_producer:
             data.append(('audio-encoder', self.audio))
         else:
             self.audio.hide()
             self.label_audio.hide()
 
-        video_producer = production.get_video_producer()
+        video_producer = production.getVideoProducer()
         if video_producer:
             data.append(('video-encoder', self.video))
         else:
@@ -129,30 +129,30 @@
         # Because it means we're pressing "back" in the wizard and the
         # combo is already populated.
         if not len(self.video) or not len(self.audio):
-            self._populate_combos(data)
+            self._populateCombos(data)
 
-    def get_next(self):
+    def getNext(self):
         if self.wizard.hasVideo():
-            return self._get_video_page()
+            return self._getVideoPage()
         elif self.wizard.hasAudio():
-            return self._get_audio_page()
+            return self._getAudioPage()
         else:
             return None
 
     # Private
 
-    def _populate_combos(self, combos, provides=None):
+    def _populateCombos(self, combos, provides=None):
         for ctype, combo in combos:
             d = self.wizard.getWizardEntries(
                 wizardTypes=[ctype],
                 provides=provides)
-            d.addCallback(self._add_entries, ctype, combo)
+            d.addCallback(self._addEntries, ctype, combo)
             combo.prefill([('...', None)])
             combo.set_sensitive(False)
         self.wizard.waitForTask('querying encoders')
         d.addCallback(lambda x: self.wizard.taskFinished())
 
-    def _add_entries(self, entries, ctype, combo):
+    def _addEntries(self, entries, ctype, combo):
         self.debug('adding entries for ctype %s: %r', ctype, entries)
         data = []
         for entry in entries:
@@ -160,7 +160,7 @@
         combo.prefill(data)
         combo.set_sensitive(True)
 
-    def _create_dummy_model(self, entry):
+    def _createDummyModel(self, entry):
         if entry.type == 'audio-encoder':
             encoder = AudioEncoder()
         elif entry.type == 'video-encoder':
@@ -172,73 +172,73 @@
         encoder.worker = self.worker
 
         if entry.type == 'audio-encoder':
-            self._audio_encoder = encoder
+            self._audioEncoder = encoder
         else:
-            self._video_encoder = encoder
+            self._videoEncoder = encoder
 
-    def _load_plugin(self, entry):
-        def got_factory(factory):
+    def _loadPlugin(self, entry):
+        def gotFactory(factory):
             return factory(self.wizard)
 
         def no_bundle(failure):
             failure.trap(NoBundleError)
 
-        d = self.wizard.get_wizard_entry(entry.component_type)
-        d.addCallback(got_factory)
+        d = self.wizard.getWizardEntry(entry.component_type)
+        d.addCallback(gotFactory)
         d.addErrback(no_bundle)
 
         return d
 
-    def _load_step(self, combo):
+    def _loadStep(self, combo):
         entry = combo.get_selected()
-        def plugin_loaded(plugin, entry):
+        def pluginLoaded(plugin, entry):
             if plugin is None:
-                self._create_dummy_model(entry)
+                self._createDummyModel(entry)
                 return None
             # FIXME: verify that factory implements IEncoderPlugin
             step = plugin.getConversionStep()
             if isinstance(step, WorkerWizardStep):
                 step.worker = self.worker
-                step.worker_changed(self.worker)
+                step.workerChanged(self.worker)
             return step
 
-        d = self._load_plugin(entry)
-        d.addCallback(plugin_loaded, entry)
+        d = self._loadPlugin(entry)
+        d.addCallback(pluginLoaded, entry)
 
         return d
 
-    def _get_audio_page(self):
-        def step_loaded(step):
+    def _getAudioPage(self):
+        def stepLoaded(step):
             if step is not None:
-                self._audio_encoder = step.model
+                self._audioEncoder = step.model
             self.wizard.taskFinished()
             return step
         self.wizard.waitForTask('audio encoder page')
-        d = self._load_step(self.audio)
-        d.addCallback(step_loaded)
+        d = self._loadStep(self.audio)
+        d.addCallback(stepLoaded)
         return d
 
-    def _get_video_page(self):
-        def step_loaded(step):
+    def _getVideoPage(self):
+        def stepLoaded(step):
             if step is not None:
-                self._video_encoder = step.model
+                self._videoEncoder = step.model
             self.wizard.taskFinished()
             return step
         self.wizard.waitForTask('video encoder page')
-        d = self._load_step(self.video)
-        d.addCallback(step_loaded)
+        d = self._loadStep(self.video)
+        d.addCallback(stepLoaded)
         return d
 
-    def _muxer_changed(self):
+    def _muxerChanged(self):
         muxer_entry = self.muxer.get_selected()
         # '...' used while waiting for the query to be done
         if muxer_entry is None:
             return
-        self._populate_combos([('audio-encoder', self.audio),
+        self._populateCombos([('audio-encoder', self.audio),
                                ('video-encoder', self.video)],
                               provides=muxer_entry.getAcceptedMediaTypes())
 
     # Callbacks
 
     def on_muxer__changed(self, combo):
-        self._muxer_changed()
+        self._muxerChanged()

Modified: flumotion/trunk/flumotion/wizard/interfaces.py
==============================================================================
--- flumotion/trunk/flumotion/wizard/interfaces.py	(original)
+++ flumotion/trunk/flumotion/wizard/interfaces.py	Mon Apr 28 16:58:15 2008
@@ -86,7 +86,7 @@
         """
 
     # FIXME: Rename to workerChanged
-    def worker_changed(worker):
+    def workerChanged(worker):
         """Called when the worker for the step changed.
         @param worker: the worker
         @type worker: L{WorkerComponentUIState}

Modified: flumotion/trunk/flumotion/wizard/overlaystep.py
==============================================================================
--- flumotion/trunk/flumotion/wizard/overlaystep.py	(original)
+++ flumotion/trunk/flumotion/wizard/overlaystep.py	Mon Apr 28 16:58:15 2008
@@ -35,7 +35,7 @@
 
     def __init__(self, video_producer):
         super(Overlay, self).__init__()
-        self._video_producer = video_producer
+        self._videoProducer = video_producer
         self.can_overlay = False
         self.show_logo = True
         self.properties.show_text = True
@@ -57,8 +57,8 @@
         if not self.properties.show_text:
             del p.text
 
-        p.width = self._video_producer.getWidth()
-        p.height = self._video_producer.getHeight()
+        p.width = self._videoProducer.getWidth()
+        p.height = self._videoProducer.getHeight()
 
         return p
 
@@ -88,24 +88,24 @@
         self.add_proxy(self.model, ['show_logo'])
         self.add_proxy(self.model.properties, ['show_text', 'text'])
 
-    def worker_changed(self, worker):
+    def workerChanged(self, worker):
         self.model.worker = worker
-        self._check_elements()
+        self._checkElements()
 
-    def get_next(self):
+    def getNext(self):
         if self.wizard.hasAudio():
-            return self.wizard.get_step('Production').get_audio_step()
+            return self.wizard.getStep('Production').getAudioStep()
 
         return None
 
     # Private API
 
-    def _set_sensitive(self, sensitive):
+    def _setSensitive(self, sensitive):
         self.show_text.set_sensitive(sensitive)
         self.show_logo.set_sensitive(sensitive)
         self.text.set_sensitive(sensitive)
 
-    def _check_elements(self):
+    def _checkElements(self):
         self.model.can_overlay = False
         def importError(error):
             self.info('could not import PIL')
@@ -123,7 +123,7 @@
             message.id = 'module-PIL'
             self.wizard.add_msg(message)
             self.wizard.taskFinished()
-            self._set_sensitive(False)
+            self._setSensitive(False)
 
         def checkImport(unused):
             self.wizard.taskFinished()
@@ -141,19 +141,19 @@
                     T_(N_("\n\nClick \"Forward\" to proceed without overlay.")))
                 self.wizard.add_msg(message)
                 self.wizard.taskFinished()
-                self._set_sensitive(False)
+                self._setSensitive(False)
                 return
             else:
                 self.wizard.clear_msg('overlay')
 
             # now check import
-            d = self.wizard.check_import(self.worker, 'PIL')
+            d = self.wizard.checkImport(self.worker, 'PIL')
             d.addCallback(checkImport)
             d.addErrback(importError)
 
         self.wizard.waitForTask('overlay')
         # first check elements
-        d = self.wizard.check_elements(
+        d = self.wizard.checkElements(
             self.worker, 'pngenc', 'ffmpegcolorspace', 'videomixer')
         d.addCallback(checkElements)
 

Modified: flumotion/trunk/flumotion/wizard/productionsteps.py
==============================================================================
--- flumotion/trunk/flumotion/wizard/productionsteps.py	(original)
+++ flumotion/trunk/flumotion/wizard/productionsteps.py	Mon Apr 28 16:58:15 2008
@@ -44,8 +44,8 @@
     icon = 'source.png'
 
     def __init__(self, wizard):
-        self._audio_producer = None
-        self._video_producer = None
+        self._audioProducer = None
+        self._videoProducer = None
         self._loadedSteps = None
         WizardStep.__init__(self, wizard)
 
@@ -69,52 +69,52 @@
         """
         return self.has_video.get_active()
 
-    def get_audio_producer(self):
+    def getAudioProducer(self):
         """Returns the selected audio producer or None
         @returns: producer or None
         @rtype: L{flumotion.wizard.models.AudioProducer}
         """
         if self.has_audio.get_active():
-            return self._audio_producer
+            return self._audioProducer
 
-    def get_video_producer(self):
+    def getVideoProducer(self):
         """Returns the selected video producer or None
         @returns: producer or None
         @rtype: L{flumotion.wizard.models.VideoProducer}
         """
         if self.has_video.get_active():
-            return self._video_producer
+            return self._videoProducer
 
-    def get_video_step(self):
+    def getVideoStep(self):
         """Return the video step to be shown, given the currently
         selected values in this step
         @returns: video step
         @rtype: a deferred returning a L{basesteps.VideoProducerStep} instance
         """
-        def step_loaded(step):
+        def stepLoaded(step):
             if step is not None:
-                self._video_producer = step.model
+                self._videoProducer = step.model
             self.wizard.taskFinished()
             return step
         self.wizard.waitForTask('video producer step')
-        d = self._load_step(self.video, 'video')
-        d.addCallback(step_loaded)
+        d = self._loadStep(self.video, 'video')
+        d.addCallback(stepLoaded)
         return d
 
-    def get_audio_step(self):
+    def getAudioStep(self):
         """Return the audio step to be shown, given the currently
         selected values in this step
         @returns: audio step
         @rtype: a deferred returning a L{basesteps.AudioProducerStep} instance
         """
-        def step_loaded(step):
+        def stepLoaded(step):
             if step is not None:
-                self._audio_producer = step.model
+                self._audioProducer = step.model
             self.wizard.taskFinished()
             return step
         self.wizard.waitForTask('audio producer step')
-        d = self._load_step(self.audio, 'audio')
-        d.addCallback(step_loaded)
+        d = self._loadStep(self.audio, 'audio')
+        d.addCallback(stepLoaded)
         return d
 
     # WizardStep
@@ -131,20 +131,20 @@
         tips.set_tip(self.has_video, _('If you want to stream video'))
         tips.set_tip(self.has_audio, _('If you want to stream audio'))
 
-        self._populate_combos()
+        self._populateCombos()
 
-    def get_next(self):
+    def getNext(self):
         if self.has_video.get_active():
-            return self.get_video_step()
+            return self.getVideoStep()
         elif self.has_audio.get_active():
-            return self.get_audio_step()
+            return self.getAudioStep()
         else:
             raise AssertionError
 
     # Private API
 
-    def _populate_combos(self):
-        def got_entries(entries, combo, default_type):
+    def _populateCombos(self):
+        def gotEntries(entries, combo, default_type):
             data = []
             default = None
             for entry in entries:
@@ -162,7 +162,7 @@
             ('audio-producer', self.audio, 'audiotest-producer')]:
             d = self.wizard.getWizardEntries(
                 wizardTypes=[ctype])
-            d.addCallback(got_entries, combo, default_type)
+            d.addCallback(gotEntries, combo, default_type)
             combo.prefill([('...', None)])
             combo.set_sensitive(False)
 
@@ -172,28 +172,28 @@
             self._loadedSteps = True
         d.addCallback(done)
 
-    def _load_plugin(self, component_type, type):
-        def got_factory(factory):
+    def _loadPlugin(self, component_type, type):
+        def gotFactory(factory):
             return factory(self.wizard)
 
         def noBundle(failure):
             failure.trap(NoBundleError)
 
-        d = self.wizard.get_wizard_entry(component_type)
-        d.addCallback(got_factory)
+        d = self.wizard.getWizardEntry(component_type)
+        d.addCallback(gotFactory)
         d.addErrback(noBundle)
 
         return d
 
-    def _load_step(self, combo, type):
-        def plugin_loaded(plugin, entry):
+    def _loadStep(self, combo, type):
+        def pluginLoaded(plugin, entry):
             # FIXME: verify that factory implements IProductionPlugin
             step = plugin.getProductionStep(type)
             return step
 
         entry = combo.get_selected()
-        d = self._load_plugin(entry, type)
-        d.addCallback(plugin_loaded, entry)
+        d = self._loadPlugin(entry, type)
+        d.addCallback(pluginLoaded, entry)
 
         return d
 
@@ -207,7 +207,7 @@
         if has_audio or has_video:
             can_continue = True
 
-        self.wizard.block_next(not can_continue)
+        self.wizard.blockNext(not can_continue)
 
     # Callbacks
 

Modified: flumotion/trunk/flumotion/wizard/worker.py
==============================================================================
--- flumotion/trunk/flumotion/wizard/worker.py	(original)
+++ flumotion/trunk/flumotion/wizard/worker.py	Mon Apr 28 16:58:15 2008
@@ -82,10 +82,10 @@
         self._combobox.pack_start(cell, True)
         self._combobox.add_attribute(cell, 'text', 0)
 
-        def on_changed(cb):
-            self.emit('worker-selected', self.get_worker())
+        def onChanged(cb):
+            self.emit('worker-selected', self.getWorker())
 
-        self._combobox.connect('changed', on_changed)
+        self._combobox.connect('changed', onChanged)
         self._combobox.show()
         # GTK 2.4
         try:
@@ -95,21 +95,21 @@
             pass
         a.add(self._combobox)
 
-    def set_worker_heaven_state(self, whs):
+    def setWorkerHeavenState(self, whs):
         self._combobox.set_model(WorkerListStore(whs))
-        self.select_worker(None)
+        self.selectWorker(None)
 
-        def on_model_changed(model):
-            if not self.get_worker():
+        def onModelChanged(model):
+            if not self.getWorker():
                 # need to select a new worker
-                self.select_worker(None) # will emit if worker selected
-                if not self.get_worker():
+                self.selectWorker(None) # will emit if worker selected
+                if not self.getWorker():
                     # no workers present!
                     self.emit('worker-selected', None)
 
-        self._combobox.get_model().connect('changed', on_model_changed)
+        self._combobox.get_model().connect('changed', onModelChanged)
 
-    def select_worker(self, worker):
+    def selectWorker(self, worker):
         # worker == none means select first worker
         for r in self._combobox.get_model():
             if not worker or r.model.get_value(r.iter, 0) == worker:
@@ -120,14 +120,14 @@
             # FIXME: let's not print, have correct logging
             print 'warning: worker %s not available' % worker
 
-    def get_worker(self):
+    def getWorker(self):
         i = self._combobox.get_active_iter()
         if i:
             return self._combobox.get_model().get_value(i, 0)
 
         return None
 
-    def notify_selected(self):
-        self.emit('worker-selected', self.get_worker())
+    def notifySelected(self):
+        self.emit('worker-selected', self.getWorker())
 
 gobject.type_register(WorkerList)

Modified: flumotion/trunk/flumotion/wizard/workerstep.py
==============================================================================
--- flumotion/trunk/flumotion/wizard/workerstep.py	(original)
+++ flumotion/trunk/flumotion/wizard/workerstep.py	Mon Apr 28 16:58:15 2008
@@ -30,14 +30,14 @@
         WizardStep.__init__(self, wizard)
         self.worker = None
 
-    def worker_changed(self, worker):
+    def workerChanged(self, worker):
         """This is called when a worker changed.
         Can be overridden in a subclass
         @param worker: the new worker
         """
 
-    def run_in_worker(self, module, function, *args, **kwargs):
-        return self.wizard.run_in_worker(self.worker, module, function,
+    def runInWorker(self, module, function, *args, **kwargs):
+        return self.wizard.runInWorker(self.worker, module, function,
                                          *args, **kwargs)
 
 


More information about the flumotion-commit mailing list
--- flumotion/trunk/flumotion/component/consumers/httpstreamer/httpstreamer_wizard.py	(original)
+++ flumotion/trunk/flumotion/component/consumers/httpstreamer/httpstreamer_wizard.py	Mon Apr 28 16:58:15 2008
@@ -266,10 +266,10 @@
         return 'http-streamer'
 
     def getServerConsumers(self):
-        source_step = self.wizard.get_step('Production')
+        source_step = self.wizard.getStep('Production')
         return self.plugarea.getServerConsumers(
-           source_step.get_audio_producer(),
-           source_step.get_video_producer())
+           source_step.getAudioProducer(),
+           source_step.getVideoProducer())
 
     def getPorters(self):
         return self.plugarea.getPorters()
@@ -289,7 +289,7 @@
         self.main_vbox.pack_start(self.plugarea, False, False)
         self.plugarea.show()
 
-        self._populate_plugins()
+        self._populatePlugins()
 
         self.add_proxy(self.model,
                        ['has_client_limit',
@@ -305,17 +305,17 @@
         self.mount_point.set_text("/")
 
     def activated(self):
-        self._check_elements()
+        self._checkElements()
         self._verify()
 
-    def worker_changed(self, worker):
+    def workerChanged(self, worker):
         self.model.worker = worker
-        self._check_elements()
+        self._checkElements()
 
     # Private
 
-    def _populate_plugins(self):
-        def got_entries(entries):
+    def _populatePlugins(self):
+        def gotEntries(entries):
             log.debug('httpwizard', 'got %r' % (entries,))
             for entry in entries:
                 if not self._canAddPlug(entry):
@@ -323,8 +323,8 @@
                 def response(factory, entry):
                     # FIXME: verify that factory implements IHTTPConsumerPlugin
                     plugin = factory(self.wizard)
-                    if hasattr(plugin, 'worker_changed'):
-                        d = plugin.worker_changed(self.worker)
+                    if hasattr(plugin, 'workerChanged'):
+                        d = plugin.workerChanged(self.worker)
                         def cb(found, plugin, entry):
                             if found:
                                 self._addPlug(
@@ -332,11 +332,11 @@
                         d.addCallback(cb, plugin, entry)
                     else:
                         self._addPlug(plugin, N_(entry.description))
-                d = self.wizard.get_wizard_plug_entry(entry.component_type)
+                d = self.wizard._getWizardPlugEntry(entry.component_type)
                 d.addCallback(response, entry)
 
         d = self.wizard.getWizardEntries(wizardTypes=['http-consumer'])
-        d.addCallbacks(got_entries)
+        d.addCallbacks(gotEntries)
 
     def _canAddPlug(self, entry):
         # This function filters out entries which are
@@ -355,14 +355,14 @@
             else:
                 raise AssertionError
 
-        encoding_step = self.wizard.get_step('Encoding')
-        if encoding_step.get_muxer_format() not in muxerTypes:
+        encoding_step = self.wizard.getStep('Encoding')
+        if encoding_step.getMuxerFormat() not in muxerTypes:
             return False
 
-        audio_format = encoding_step.get_audio_format()
-        video_format = encoding_step.get_video_format()
-        if ((audio_format and audio_format not in audioTypes) or
-            (video_format and video_format not in videoTypes)):
+        audioFormat = encoding_step.getAudioFormat()
+        videoFormat = encoding_step.getVideoFormat()
+        if ((audioFormat and audioFormat not in audioTypes) or
+            (videoFormat and videoFormat not in videoTypes)):
             return False
 
         return True
@@ -370,7 +370,7 @@
     def _addPlug(self, plugin, description):
         self.plugarea.addPlug(plugin, description)
 
-    def _check_elements(self):
+    def _checkElements(self):
         self.wizard.waitForTask('http streamer check')
 
         def importError(failure):
@@ -392,7 +392,7 @@
             self.wizard.taskFinished()
 
         def checkWorkerHostname(unused):
-            d = self.wizard.run_in_worker(
+            d = self.wizard.runInWorker(
                 self.worker, 'flumotion.worker.checks.http',
                 'runHTTPStreamerChecks')
             d.addCallback(finished)
@@ -411,15 +411,15 @@
             self.wizard.clear_msg('httpstreamer')
 
             # now check import
-            d = self.wizard.check_import(self.worker, 'twisted.web')
+            d = self.wizard.checkImport(self.worker, 'twisted.web')
             d.addCallback(checkWorkerHostname)
             d.addErrback(importError)
 
         # first check elements
-        d = self.wizard.require_elements(self.worker, 'multifdsink')
+        d = self.wizard.requireElements(self.worker, 'multifdsink')
         d.addCallback(checkElements)
 
         # require_elements calls check_elements which unconditionally
         # unblocks the next call. Work around that behavior here.
         d.addErrback(lambda unused: self.wizard.taskFinished(True))
 
@@ -433,14 +433,14 @@
     def _update_blocked(self):
         # FIXME: This should be updated and only called when all pending
         #        tasks are done.
-        self.wizard.block_next(
+        self.wizard.blockNext(
             self.wizard.pendingTask() or self.mount_point.get_text() == '')
 
     # Callbacks
 
     def on_mount_point_changed(self, entry):
         self._verify()
-        self.wizard.block_next(self.model.has_cortado and entry.get_text() == "/")
+        self.wizard.blockNext(self.model.has_cortado and entry.get_text() == "/")
 
     def on_has_client_limit_toggled(self, checkbutton):
         self._verify()
@@ -411,15 +411,15 @@
         d.addCallback(checkElements)
 
-        # require_elements calls check_elements which unconditionally
+        # requireElements calls checkElements which unconditionally
         # unblocks the next call. Work around that behavior here.
         d.addErrback(lambda unused: self.wizard.taskFinished(True))

Modified: flumotion/trunk/flumotion/component/consumers/shout2/shout2_wizard.py
==============================================================================